==> haskell-http-date-0.0.6.1-28-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-date
version: 0.0.6.1
id: http-date-0.0.6.1-5v2g2AWG8rqEKczWoWv4DN
key: http-date-0.0.6.1-5v2g2AWG8rqEKczWoWv4DN
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP Date parser/formatter
description:
    Fast parser and formatter for HTTP Date
category: Network, Web
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Date
hidden-modules: Network.HTTP.Date.Converter
                Network.HTTP.Date.Formatter Network.HTTP.Date.Types
                Network.HTTP.Date.Parser
abi: 645927d7d5f527ea2dc7fd48ab3e9747
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http-date-0.0.6.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/http-date-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/http-date-0.0.6.1
hs-libraries: HShttp-date-0.0.6.1-5v2g2AWG8rqEKczWoWv4DN
depends:
    base-4.10.0.0 array-0.5.2.0
    attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j bytestring-0.10.8.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             array-0.5.2.0=044554210403f250e868a2183de060a9
             attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=408c5a9ef40ae69c083ed9d4aba83592
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html: /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-date-0.0.6.1-30-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-date
version: 0.0.6.1
id: http-date-0.0.6.1-Kag7ZMXScfO1ZYRXttKgIS
key: http-date-0.0.6.1-Kag7ZMXScfO1ZYRXttKgIS
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP Date parser/formatter
description:
    Fast parser and formatter for HTTP Date
category: Network, Web
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Date
hidden-modules: Network.HTTP.Date.Converter
                Network.HTTP.Date.Formatter Network.HTTP.Date.Types
                Network.HTTP.Date.Parser
abi: 888b9985b2884083dee74b20dc4d55fc
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http-date-0.0.6.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/http-date-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/http-date-0.0.6.1
hs-libraries: HShttp-date-0.0.6.1-Kag7ZMXScfO1ZYRXttKgIS
depends:
    base-4.10.0.0 array-0.5.2.0
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm bytestring-0.10.8.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             array-0.5.2.0=044554210403f250e868a2183de060a9
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html: /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
